==> nextcloud-27.1.11.tgz: nextcloud/apps/survey_client/l10n/ga.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Seoladh an tuairisc dheireanach ar: {on}",
    "An error occurred while sending your report." : "Tharla earráid agus do thuairisc á seoladh.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Liosta aipeanna  <em>(do gach aip: ainm, leagan, stádas cumasaithe)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Timpeallacht bunachar sonraí<em>(cineál, leagan, méid an bhunachair sonraí)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Faisnéis chriptiúcháin <em>(an bhfuil sé cumasaithe?, cad é an modúl réamhshocraithe)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Líon na scaireanna <em>(de réir cineáil agus socrú ceada)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Timpeallacht PHP <em>(leagan, teorainn chuimhne, uas-am forghníomhaithe, uasmhéid comhaid)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Sonraí shampla an fhreastalaí <em>(leagan, memcache a úsáideadh, stádas an ghlasála/réamhamhairc/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Staidreamh <em>(líon comhad, úsáideoirí, stórais de réir cineáil, nótaí tráchta agus clibeanna)</em>",
    "Usage survey" : "Suirbhé úsáide",
    "Help improve Nextcloud" : "Cabhrú le Nextcloud a fheabhsú",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Ar mhaith leat cabhrú linn feabhas a chur ar Nextcloud trí roinnt sonraí gan ainm a sholáthar faoi do shocrú agus d’úsáid? Is féidir leat é a dhíchumasú am ar bith sna socruithe riaracháin arís.",
    "Not now" : "Ní anois",
    "Send usage" : "Seol úsáid",
    "Never" : "Riamh",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Seoltar sonraí gan ainm chuig Nextcloud chun cabhrú linn feabhas a chur ar Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Seoltar sonraí gan ainm chuig Nextcloud chun cabhrú linn feabhas a chur ar Nextcloud. tu\nBíonn smacht iomlán ag \t\t i gcónaí ar an ábhar a sheoltar chuig Nextcloud agus is féidir é a dhíchumasú\n\t\t arís é am ar bith.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Is féidir leat cabhrú le Nextcloud a fheabhsú trí roinnt sonraí a sheoladh chugainn faoi do shocrú agus úsáid reatha.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Glacaimid do phríobháideachas dáiríre. Tá seoladh sonraí díchumasaithe de réir réamhshocraithe, agus má roghnaíonn tú é a chur ar siúl, déanfar é a anaithnid ar dtús, agus tugtar an rogha duit cad iad na rudaí atá le roinnt. Nuair a fhaightear tuairisc, baintear an ceann roimhe sin. Uaslódáil tuairisc ghlan chun na sonraí go léir atá stóráilte ar an bhfreastalaí faoi láthair a scriosadh",
    "Send new report now" : "Seol tuairisc nua anois",
    "Send usage survey monthly" : "Seol suirbhé úsáide go míosúil",
    "Data to send" : "Sonraí le seoladh",
    "Last report sent on: %s" : "Seoladh an tuairisc dheireanach ar: %s",
    "Last report" : "Tuairisc dheireanach"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/survey_client/l10n/ga.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Seoladh an tuairisc dheireanach ar: {on}",
    "An error occurred while sending your report." : "Tharla earráid agus do thuairisc á seoladh.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Liosta aipeanna  <em>(do gach aip: ainm, leagan, stádas cumasaithe)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Timpeallacht bunachar sonraí<em>(cineál, leagan, méid an bhunachair sonraí)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Faisnéis chriptiúcháin <em>(an bhfuil sé cumasaithe?, cad é an modúl réamhshocraithe)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Líon na scaireanna <em>(de réir cineáil agus socrú ceada)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Timpeallacht PHP <em>(leagan, teorainn chuimhne, uas-am forghníomhaithe, uasmhéid comhaid)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Sonraí shampla an fhreastalaí <em>(leagan, memcache a úsáideadh, stádas an ghlasála/réamhamhairc/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Staidreamh <em>(líon comhad, úsáideoirí, stórais de réir cineáil, nótaí tráchta agus clibeanna)</em>",
    "Usage survey" : "Suirbhé úsáide",
    "Help improve Nextcloud" : "Cabhrú le Nextcloud a fheabhsú",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Ar mhaith leat cabhrú linn feabhas a chur ar Nextcloud trí roinnt sonraí gan ainm a sholáthar faoi do shocrú agus d’úsáid? Is féidir leat é a dhíchumasú am ar bith sna socruithe riaracháin arís.",
    "Send usage" : "Seol úsáid",
    "Not now" : "Ní anois",
    "Never" : "Riamh",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Seoltar sonraí gan ainm chuig Nextcloud chun cabhrú linn feabhas a chur ar Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Seoltar sonraí gan ainm chuig Nextcloud chun cabhrú linn feabhas a chur ar Nextcloud. tu\nBíonn smacht iomlán ag \t\t i gcónaí ar an ábhar a sheoltar chuig Nextcloud agus is féidir é a dhíchumasú\n\t\t arís é am ar bith.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Is féidir leat cabhrú le Nextcloud a fheabhsú trí roinnt sonraí a sheoladh chugainn faoi do shocrú agus úsáid reatha.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "Glacaimid do phríobháideachas dáiríre. Tá seoladh sonraí díchumasaithe de réir réamhshocraithe, agus má roghnaíonn tú é a chur ar siúl, déanfar é a anaithnid ar dtús, agus tugtar an rogha duit cad iad na rudaí atá le roinnt. Nuair a fhaightear tuairisc, baintear an ceann roimhe sin. Chun na sonraí úsáide stóráilte a scriosadh, uaslódáil tuairisc folamh trí na boscaí go léir a dhíthiceáil agus tuairisc nua a sheoladh.",
    "Send new report now" : "Seol tuairisc nua anois",
    "Send usage survey monthly" : "Seol suirbhé úsáide go míosúil",
    "Data to send" : "Sonraí le seoladh",
    "Last report sent on: %s" : "Seoladh an tuairisc dheireanach ar: %s",
    "Last report" : "Tuairisc dheireanach"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
